{-# LANGUAGE Trustworthy #-}
-- | Reexports "Test.Hspec" from a @Trustworthy@ module.
module TestHspecTrustworthy (module Test.Hspec) where

import Test.Hspec
